@@ -346,3 +346,16 @@ window_pt (Window * wp)
         return get_buffer_pt (wp->bp);
     }
 }
+
+bool
+window_top_visible (Window * wp)
+{
+  return window_pt (wp).n == get_window_topdelta (wp);
+}
+
+bool
+window_bottom_visible (Window * wp)
+{
+  return window_pt (wp).n + (get_window_eheight (wp) - get_window_topdelta (wp)) >
+    get_buffer_last_line (get_window_bp (wp));
+}
